@@ -1,11 +1,30 @@
 package Catmandu::Solr;
 # ABSTRACT: Catmandu modules for working with solr endpoints
-our $VERSION = "0.03";
+our $VERSION = "0.0301";
 
 =head1 NAME
 
 Catmandu::Solr - Catmandu modules for working with solr endpoints
 
+=head1 SYNOPSIS
+
+    # From the command line
+
+    # Import data into Solr
+    $ catmandu import JSON to Solr  < data.json
+
+    # Export data from ElasticSearch
+    $ catmandu export Solr to JSON > data.json
+
+    # Export only one record
+    $ catmandu export Solr --id 1234
+
+    # Export using an Solr query
+    $ catmandu export Solr --query "name:Recruitment OR name:college"
+
+    # Export using a CQL query (needs a CQL mapping)
+    $ catmandu export Solr --q "name any college"
+
 =head1 AUTHOR
 
 Nicolas Steenlant, C<< nicolas.steenlant at ugent.be >>
