@@ -3,6 +3,7 @@ package Catmandu::Store::Solr;
 use Catmandu::Sane;
 use Catmandu::Util qw(:is :array);
 use Moo;
+use MooX::Aliases;
 use WebService::Solr;
 use Catmandu::Store::Solr::Bag;
 use Catmandu::Error;
@@ -16,10 +17,28 @@ Catmandu::Store::Solr - A searchable store backed by Solr
 
 =cut
 
-our $VERSION = '0.03';
+our $VERSION = '0.0301';
 
 =head1 SYNOPSIS
 
+    # From the command line
+
+    # Import data into Solr
+    $ catmandu import JSON to Solr  < data.json
+
+    # Export data from ElasticSearch
+    $ catmandu export Solr to JSON > data.json
+
+    # Export only one record
+    $ catmandu export Solr --id 1234
+
+    # Export using an Solr query
+    $ catmandu export Solr --query "name:Recruitment OR name:college"
+
+    # Export using a CQL query (needs a CQL mapping)
+    $ catmandu export Solr --q "name any college"
+
+    # From Perl
     use Catmandu::Store::Solr;
 
     my $store = Catmandu::Store::Solr->new(url => 'http://localhost:8983/solr' );
@@ -63,8 +82,8 @@ has solr => (
     builder => '_build_solr',
 );
 
-has id_field  => (is => 'ro', default => sub { '_id' });
-has bag_field => (is => 'ro', default => sub { '_bag' });
+has bag_key => (is => 'lazy', alias => 'bag_field');
+
 has on_error => (
     is => 'ro',
     isa => sub {
@@ -96,6 +115,10 @@ sub _build_solr {
     WebService::Solr->new($_[0]->url, {autocommit => 0, default_params => {wt => 'json'}});
 }
 
+sub _build_id_key {
+    $_[0]->key_for('bag');
+}
+
 sub transaction {
     my($self,$sub)=@_;
 
